@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-form
 version: 1.4.7
-id: yesod-form-1.4.7-f6d1e11ea63e1cbc5a2a6488d647899b
-key: yesod_DdcndPuPzR5KGOjUDFmFZU
+id: yesod-form-1.4.7-6a275c9e9130fcb166b96e9c28a6cb8b
+key: yesod_H6JVbIXEpxKH5uqsQBu3QX
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-form-1.4.7
-hs-libraries: HSyesod-form-1.4.7-DdcndPuPzR5KGOjUDFmFZU
+hs-libraries: HSyesod-form-1.4.7-H6JVbIXEpxKH5uqsQBu3QX
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -41,8 +41,8 @@ depends:
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    persistent-2.2.4.1-06cdd104cf52ce01e8563b1ef8106c7c
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
@@ -51,8 +51,8 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
     xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
-    yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
-    yesod-persistent-1.4.0.4-46b19a60c1c766dabb361044b5599141
+    yesod-core-1.4.20-b033425e59f14830b0f582c5aa97dfc9
+    yesod-persistent-1.4.0.4-ad1a95adedfa128856dec4233422bbe5
 haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
 haddock-html: /usr/share/doc/haskell-yesod-form/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
